## Cloudflare Workers AI Integration for Drupal

**Seamlessly integrate Cloudflare Workers AI into your Drupal website** with this powerful module. Leverage **serverless AI capabilities** for real-time **text generation**, **image classification**, **audio transcription**, and more — directly from your Drupal interface.

This module is part of the [AI Provider ecosystem](https://www.drupal.org/project/ai_provider) and enables your Drupal site to connect to **Cloudflare Workers AI**, a fully serverless platform offering **50+ free AI models** with automatic scaling, no infrastructure overhead, and lightning-fast performance.

### Features

- Access over **50+ free AI models** via [Cloudflare Workers AI](https://developers.cloudflare.com/workers-ai/models/)
- Enhance your Drupal site with cutting-edge artificial intelligence:
  - **Connect to 50+ free AI models** on Cloudflare Workers AI
  - AI-powered capabilities:
    - Text generation and summarization
    - Image recognition and object detection
    - Audio-to-text transcription
    - And more
  - **Deep Drupal integration** via the [AI Provider module](https://www.drupal.org/project/ai_provider)
  - Easy API setup using your Cloudflare credentials
  - Developer-friendly: extendable hooks and services for custom AI logic
  - Serverless architecture — no infrastructure to manage or scale
- Fully integrates with Drupal via the [AI Provider](https://www.drupal.org/project/ai_provider) ecosystem
- Simple API setup — just add your Cloudflare credentials
- Extendable hooks and services to use AI results programmatically
- No need to run your own models — inference happens at the edge with **zero server overhead**

### Requirements

- Creative Mind ✍️  
- Drupal 10.1 or higher  
- PHP 8.1+  
- AI Provider module installed and enabled  
- A valid Cloudflare account and API token with Workers AI access  

### Post-Installation

Install the Cloudflare Workers AI Provider module using Composer.

### Setup

#### Getting Cloudflare credentials:

1. Login/Create account in [Cloudflare Dashboard](https://dash.cloudflare.com)
2. Note the URL in your address bar — it will look like:  
   `https://dash.cloudflare.com/{YOUR_ACCOUNT_ID}/home/...`  
   Copy the `{YOUR_ACCOUNT_ID}` and save it somewhere.
3. Click on the profile icon → [Profile → API Tokens](https://dash.cloudflare.com/profile/api-tokens)
4. Click on **Create Token**  
   ![Create Token](https://www.drupal.org/files/cf-1_lijx0g_0.jpg)
5. Click on **Use Template** next to *Workers AI*  
   ![Use Template](https://www.drupal.org/files/cf-2_x4ssa4_0.jpg)
6. In **Account Resources**, select **All accounts**  
   ![Account Resources](https://www.drupal.org/files/cf-3_nsa1ul_0.jpg)
7. Click **Continue to summary**  
   ![Continue to Summary](https://www.drupal.org/files/cf-4_uscuxw_0.jpg)
8. Review your settings and click **Create Token**  
   ![Create Token](https://www.drupal.org/files/cf-5_eilgxr_0.jpg)
9. Your API token is now generated — copy and save it securely. You will not be able to see it again.  
   You’ll also see a cURL request to test the token — verify to ensure it works.  
   Your Cloudflare base URL is: `https://api.cloudflare.com`  
   ![API Token Generated](https://www.drupal.org/files/cf-6_qpoov8.jpg)

---

### Additional Requirements

- A [Cloudflare Workers AI](https://developers.cloudflare.com/workers-ai) account  
- API token with access to Workers AI  

### Recommended Modules/Libraries

- [AI Provider](https://www.drupal.org/project/ai_provider) — Base module that enables AI integrations in Drupal

### Similar Projects

- [OpenAI](https://www.drupal.org/project/openai) — Paid API integration with fewer free models and higher latency

### Supporting this Module

Maintained by the open-source community. Contributions, bug reports, and feature requests are welcome on Drupal.org or GitHub.

