<?php

namespace Drupal\workers_ai_provider\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\ai\AiProviderPluginManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure Workers API access.
 */
class WorkersAiConfigForm extends ConfigFormBase {

  /**
   * Config settings.
   */
  const CONFIG_NAME = 'workers_ai_provider.settings';

  /**
   * The AI Provider service.
   *
   * @var \Drupal\ai\AiProviderPluginManager
   */
  protected $aiProviderManager;

  /**
   * Constructs a new WorkersAiConfigForm object.
   */
  final public function __construct(AiProviderPluginManager $ai_provider_manager) {
    $this->aiProviderManager = $ai_provider_manager;
  }

  /**
   * {@inheritdoc}
   */
  final public static function create(ContainerInterface $container) {
    return new static(
      $container->get('ai.provider'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'workers_ai_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::CONFIG_NAME,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::CONFIG_NAME);

    $form['api_key'] = [
      '#type' => 'key_select',
      '#title' => $this->t('Workers AI API Key'),
      '#description' => $this->t('The API Key is cloudfare api token. Can be found on <a href="https://dash.cloudflare.com/profile/api-tokens">https://dash.cloudflare.com/profile/api-tokens</a>.'),
      '#default_value' => $config->get('api_key'),
    ];
    $form['cloudfare_base_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Cloudfare Base URL'),
      '#description' => $this->t('Can be found on Cloudfare Profile <a target="_blank"href="https://dash.cloudflare.com/profile/api-tokens">https://dash.cloudflare.com/profile/api-tokens</a>.'),
      '#default_value' => $config->get('cloudfare_base_url'),
    ];
    $form['cloudfare_account_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Cloudfare Account ID'),
      '#description' => $this->t('Can be found on Cloudfare Dashboard URL.'),
      '#default_value' => $config->get('cloudfare_account_id'),
    ];
    
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Retrieve the configuration.
    $this->config(static::CONFIG_NAME)
      ->set('api_key', $form_state->getValue('api_key'))
      ->set('cloudfare_base_url', $form_state->getValue('cloudfare_base_url'))
      ->set('cloudfare_account_id', $form_state->getValue('cloudfare_account_id'))
      ->save();

    $this->aiProviderManager->defaultIfNone('chat', 'workersai', '@cf/meta/llama-2-7b-chat-fp16');

    parent::submitForm($form, $form_state);
  }

}
